-- Extra functions

-- Changes draw color to predefined ones
function color(cname, oalpha)
  if oalpha == nil then oalpha = 255 end
  if cname == "white" then
    lg.setColor(255, 255, 255, oalpha)
  end
end

-- Checks the command-line arguments table for a specific string represented by 'key', if found, returns true
function checkArgsFor(key)
  if arg == nil then
    print("No args table...")
    return
  end
  for k, v in ipairs(arg) do
    if key == v then
      print(v.." == "..key)
      return true
    else
      print(v.." ~= "..key)
    end
  end
  return false
end

-- Gets strings from the command-line arguments that append a command represented by 'key'
function getArgsFrom(key)
  local fin = string.len(key)
  if arg == nil then
    print("No args table...")
    return
  end
  for k, v in ipairs(arg) do
    local word = string.sub(v, 0, fin)
    if key == word then
      print(word.." == "..key)
      return string.sub(v, fin + 1, string.len(v))
    else
      print(word.." ~= "..key)
    end
  end
  print("\""..key.."\" not found!")
  return
end

--if not checkArgsFor("-nolog") then
if checkArgsFor("-log") then
  logtime = os.date("%m_%d_%y-%H%M%S")
  lfs.write(logtime .. ".log", "Creating new log file...Created!\r\n\r\n")
end

-- Prints text to the console as well as a log file
function log(txt, flag)
  local ltxt = "[" .. os.date("%m_%d_%y-%H%M%S") .. "]"
  if flag == 'e' then
    ltxt = ltxt .. " [ERROR] " .. txt .. "!~!"
  elseif flag == 'w' then
    ltxt = ltxt .. " [WARNING] " .. txt .. "!"
  else
    ltxt = ltxt .. " " .. txt
  end
  print(ltxt)
  if logtime ~= nil then lfs.append(logtime .. ".log", ltxt .. "\r\n") end
end

-- Opens save directory
function openDirectory()
  lsy.openURL(lfs.getSaveDirectory())
end

-- Rounds stuffs
function math.round(num, idp)
  local mult = 10^(idp or 0)
  return math.floor(num * mult + 0.5) / mult
end

-- Gets actual table size for tables with handles
function table.size(t)
  local count = 0
  for _ in pairs(t) do count = count + 1 end
  return count
end