-- RPG Project
--
-- Created by TheRedRaccoon

math.randomseed(os.time()) -- Random for days...

-- LÖVE Shortcuts
la  = love.audio
le  = love.event
lfs = love.filesystem
lf  = love.font
lg  = love.graphics
li  = love.image
lj  = love.joystick
lk  = love.keyboard
lma = love.math
lm  = love.mouse
lp  = love.physics
ls  = love.sound
lsy = love.system
lth = love.thread
lt  = love.timer
lw  = love.window


-- ==========================   ~ Game Proper ~   ==========================


require 'extra'
-- Require other peeps' libs
if checkArgsFor("-debug") then log("Debug mode activated!") deb = true require 'libs.lovedebug' end

sti = require 'libs.STI'
anim8 = require 'libs.anim8'
bump = require 'libs.bump'
timer = require 'libs.timer'

require 'libs.tserial'
require 'libs.PassCodec'
require "libs.maid64"

-- Additional requires
require "gamestates_controls"
require "mms"
require "player"
require "map"

if lsy.getOS() == "Android" or lsy.getOS() == "iOS" then mobile = true end

-- LÖVE
function love.load()
  --[[ Create a tmp folder to hold certain data while the game is running
  if not lfs.exists("tmp") then
    local ok = lfs.createDirectory("tmp")
    if ok then 
      log("\"tmp\" folder successfully created")
    else
      log("Could not create \"tmp\" folder", 'w')
    end
  end
  if lfs.exists("tmp") then
    local ok = lfs.write("tmp/openMe.txt", "If this file is here, the game did NOT exit correctly...")
    if ok then
      log("tmp folder warning text successfully created")
    else
      log("Could not create tmp warning text", 'w')
    end
  end
  
  -- Mod data setup
  if lfs.exists("mod-data.lua") then
    suc, mod = pcall(lfs.load, "mod-data.lua")
  else
    modl, modlerr = lfs.newFileData("assets/mod-loader.lua")
    if modl ~= nil then lfs.write("mod-data.lua", modl) end
    suc, mod = pcall(lfs.load, "mod-data.lua")
  end
  if mod ~= nil then
    pcall(mod)
  end
  suc = nil
  mod = nil]]
  
  
  
  -- ==========================   ~ Setup ~   ==========================
  mw, mh = 256, 224
  maid64.setup(mw, mh)
  
  testing = lg.newText(font[2], "Is this working?")
  testing:setf("\n\nHikitsune\nRed\npresents", mw, "center")
  
  whale = lg.newImage("graphics/splash/8bit_Whale_Placed.png")
  splashColor = {0, 0, 0, 0}
  
  -- SPLASH~!
  timer.tween(3, splashColor, {255, 255, 255, 255}, "in-quad", 
    function() timer.after(2,
      function() timer.tween(2, splashColor, {0, 0, 0, 0}, "in-quad",
        function() timer.after(0.5,
          function() part2 = true testing:setf("A Game\nmade with\nLOVE", mw, "center") timer.tween(2, splashColor, {255, 255, 255, 255}, "in-quad", 
            function() timer.after(2, 
              function() timer.tween(2, splashColor, {0, 0, 0, 0}, "in-quad",
                function() timer.after(0.5, function() splashoff = true newMap("test") end)
                end)
              end)
            end)
          end)
        end)
      end)
    end)
  
  tx, ty = 0, 0
  debugging = false
end

function love.update(dt)
  -- HUMP timer
  timer.update(dt)
  
  if map ~= nil then map:update(dt) end
end

function love.draw()
  maid64.start()
  
  -- ==========================   ~ Splash Screen Handling ~   ==========================
  
  lg.setColor(splashColor)
  if not splashoff then
    if part2 then
      lg.rectangle('fill', 110, 37, 2, 2)
      lg.rectangle('fill', 114, 37, 2, 2)
      lg.draw(whale, 100, 64)
    end
    lg.draw(testing, 0, 0)
  end
  
  -- ==========================   ~ Map Handling ~   ==========================
  
  color("white")
  lg.push()
  lg.translate(tx + (mw/2 - 8), ty + (mh/2 - 8))
  if map ~= nil then
    map:setDrawRange(-tx, -ty, mw, mh)
    map:draw()
    if debugging and world ~= nil then
      map:bump_draw(world)
    end
  end
  lg.pop()
  
  maid64.finish()
  
  color("white")
  if debugging or deb then
    --lg.print(math.ceil(lm.getX()/2) .. ", " .. math.ceil(lm.getY()/2), 0, 20)
    lg.print("FPS: " .. tostring(lt.getFPS()))
    lg.print(string.format("Frame time: %.3f ms", 1000 * lt.getAverageDelta()), 10, 10)
  end
end

function love.resize(w, h)
  -- this is used to resize the screen correctly
  maid64.resize(w, h)
  log("Window resized to " .. w .. " x " .. h)
end

function love.quit()
  log("Closing...")
  local tmpFileList = lfs.getDirectoryItems("tmp")
  local allok = true
  for i, f in pairs(tmpFileList) do
    local ok = lfs.remove("tmp/"..f)
    if not ok then
      allok = false
      log(f .. " was not removed", 'w')
    end
  end
  if not lfs.remove("tmp") then allok = false end
  
  if not allok then
    log("Closing process was unable to complete", 'w')
  else
    log("Closed ^_^")
  end
end